==> python_auditor-0.0.3.tar.gz: python_auditor-0.0.3/README.md <==
<p align="center">
  <a href="https://crates.io/crates/pyauditor"
    ><img
      src="https://img.shields.io/crates/v/pyauditor?style=flat-square"
      alt="Crates.io version"
  /></a>
  <a href="https://github.com/alu-schumacher/AUDITOR/actions"
    ><img
      src="https://img.shields.io/github/workflow/status/alu-schumacher/AUDITOR/Auditor/main?label=Auditor CI&style=flat-square"
      alt="GitHub Actions workflow status"
  /></a>
  <img
    src="https://img.shields.io/crates/l/auditor?style=flat-square"
    alt="License"
  />
</p>

# pyauditor

**pyauditor** is a Python library which simplifies the interaction with AUDITOR from Python.

For more information please [visit our website](https://alu-schumacher.github.io/AUDITOR/).


<p align="center">
  <a href="https://alu-schumacher.github.io/AUDITOR/">Documentation</a>
  |
  <a href="https://docs.rs/pyauditor">API Documentation</a>
</p>

## License

Licensed under either of

 - Apache License, Version 2.0, ([LICENSE-APACHE](https://github.com/ALU-Schumacher/AUDITOR/blob/main/LICENSE-APACHE) or <http://www.apache.org/licenses/LICENSE-2.0>)
 - MIT License ([LICENSE-MIT](https://github.com/ALU-Schumacher/AUDITOR/blob/main/LICENSE-MIT) or <http://opensource.org/licenses/MIT>)

at your option.

### Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.

==> python_auditor-0.0.6.tar.gz: python_auditor-0.0.6/README.md <==
<p align="center">
  <a href="https://pypi.org/project/python-auditor/">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/python-auditor?style=flat-square">
  </a>
  <a href="https://pypi.org/project/python-auditor/">
    <img alt="PyPI - Status" src="https://img.shields.io/pypi/status/python-auditor?style=flat-square">
  </a>
  <a href="https://pypi.org/project/python-auditor/">
    <img alt="PyPI - Format" src="https://img.shields.io/pypi/format/python-auditor?style=flat-square">
  </a>
  <a href="https://github.com/alu-schumacher/AUDITOR/actions"
    ><img
      src="https://img.shields.io/github/workflow/status/alu-schumacher/AUDITOR/Auditor/main?label=Auditor CI&style=flat-square"
      alt="GitHub Actions workflow status"
  /></a>
  <img
    src="https://img.shields.io/crates/l/auditor?style=flat-square"
    alt="License"
  />
</p>

# pyauditor

**pyauditor** is a Python library which simplifies the interaction with AUDITOR from Python.

For more information please [visit our website](https://alu-schumacher.github.io/AUDITOR/).


<p align="center">
  <a href="https://alu-schumacher.github.io/AUDITOR/pyauditor/">pyauditor Documentation</a>
  |
  <a href="https://alu-schumacher.github.io/AUDITOR/">Auditor Documentation</a>
</p>

## License

Licensed under either of

 - Apache License, Version 2.0, ([LICENSE-APACHE](https://github.com/ALU-Schumacher/AUDITOR/blob/main/LICENSE-APACHE) or <http://www.apache.org/licenses/LICENSE-2.0>)
 - MIT License ([LICENSE-MIT](https://github.com/ALU-Schumacher/AUDITOR/blob/main/LICENSE-MIT) or <http://opensource.org/licenses/MIT>)

at your option.

### Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.
